==> xl-security-2019.2.4-sources.jar: com/xebialabs/deployit/security/PermissionEnforcer.java <==
package com.xebialabs.deployit.security;

import com.xebialabs.deployit.repository.SearchParameters;
import com.xebialabs.deployit.security.permission.Permission;
import com.xebialabs.deployit.security.permission.PlatformPermissions;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.Authentication;
import org.springframework.stereotype.Component;

import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.List;

import static com.xebialabs.deployit.security.Permissions.authenticationToPrincipals;
import static com.xebialabs.deployit.security.Permissions.getAuthentication;
import static java.util.stream.Collectors.toList;

@Component
public class PermissionEnforcer {

    public static final String ROLE_ADMIN = "ROLE_ADMIN";

    private PermissionChecker checker;
    private final RoleService roleService;

    @Autowired
    public PermissionEnforcer(PermissionChecker checker, RoleService roleService) {
        this.checker = checker;
        this.roleService = roleService;
    }

    public boolean hasPermission(Authentication authentication, final Permission... permissions) {
        return hasPermission(authentication, Arrays.asList(permissions), "");
    }

    public boolean hasLoggedInUserPermission(final Permission... permissions) {
        Authentication authentication = getAuthentication();
        return hasPermission(authentication, Arrays.asList(permissions), "");
    }

    public boolean hasLoggedInUserPermission(Permission permission, String onConfigurationItem) {
        return hasLoggedInUserPermission(Collections.singletonList(permission), onConfigurationItem);
    }

    public boolean hasLoggedInUserPermission(List<Permission> permissions, String onConfigurationItem) {
        return hasPermission(getAuthentication(), permissions, onConfigurationItem);
    }

    public void applyLoggedInUserPermission(SearchParameters parameters, Permission permission) {
        applyLoggedInUserPermission(parameters, Collections.singletonList(permission));
    }

    public void applyLoggedInUserPermission(SearchParameters parameters, List<Permission> permissions) {
        applyPermission(parameters, getAuthentication(), permissions);
    }

    public boolean hasPermission(Authentication auth, List<Permission> permissions, String onConfigurationItem) {
        final Collection<String> allPrincipals = authenticationToPrincipals(auth);
        List<Role> allRoles = getUserRoles(auth);
        return isAdmin(allPrincipals, allRoles) || hasPermission(allRoles, permissions, onConfigurationItem);
    }

    public void applyPermission(SearchParameters parameters, Authentication auth, List<Permission> permissions) {
        final Collection<String> allPrincipals = authenticationToPrincipals(auth);
        List<Role> allRoles = getUserRoles(auth);
        if (!isAdmin(allPrincipals, allRoles)) {
            applyPermission(parameters, allRoles, permissions);
        }
    }

    public List<Role> getUserRoles(Authentication auth) {
        return roleService.getRolesFor(auth);
    }

    public boolean hasPermission(List<Role> roles, List<Permission> permissions, String onConfigurationItem) {
        return checker.checkPermission(permissions, onConfigurationItem, roles);
    }

    public void applyPermission(SearchParameters parameters, List<Role> roles, List<Permission> permissions) {
        parameters.setSecurityParameters(
                roles.stream().map(Role::getId).collect(toList()),
                permissions.stream().map(Permission::getPermissionName).collect(toList())
        );
    }

    boolean isAdmin(Collection<String> allPrincipals, List<Role> allRoles, Authentication auth) {
        Boolean isAdmin = allPrincipals.contains(ROLE_ADMIN) || checker.checkPermission(Collections.singletonList(PlatformPermissions.ADMIN), "", allRoles, auth);
        logger.trace("Admin privileges [{}] granted to {}", isAdmin ? "are" : "are not", allPrincipals);
        return isAdmin;
    }

    public boolean isAdmin(Collection<String> allPrincipals, List<Role> allRoles) {
        return isAdmin(allPrincipals, allRoles, Permissions.getAuthentication());
    }

    private static final Logger logger = LoggerFactory.getLogger(PermissionEnforcer.class);

    public boolean isCurrentUserAdmin() {
        return isAdmin(getAuthentication());
    }

    public boolean isAdmin(Authentication auth) {
        Collection<String> principals = authenticationToPrincipals(auth);
        List<Role> allRoles = roleService.getRolesFor(auth);
        return isAdmin(principals, allRoles, auth);
    }
}

==> xl-security-2019.3.10-sources.jar: com/xebialabs/deployit/security/PermissionEnforcer.java <==
package com.xebialabs.deployit.security;

import com.xebialabs.deployit.repository.SearchParameters;
import com.xebialabs.deployit.security.permission.Permission;
import com.xebialabs.deployit.security.permission.PlatformPermissions;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.Authentication;
import org.springframework.stereotype.Component;

import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.List;

import static com.xebialabs.deployit.security.Permissions.authenticationToPrincipals;
import static com.xebialabs.deployit.security.Permissions.getAuthentication;
import static java.util.stream.Collectors.toList;

@Component
public class PermissionEnforcer {

    public static final String ROLE_ADMIN = "ROLE_ADMIN";

    private PermissionChecker checker;
    private final RoleService roleService;

    @Autowired
    public PermissionEnforcer(PermissionChecker checker, RoleService roleService) {
        this.checker = checker;
        this.roleService = roleService;
    }

    public boolean hasPermission(Authentication authentication, final Permission... permissions) {
        return hasPermission(authentication, Arrays.asList(permissions), "");
    }

    public boolean hasLoggedInUserPermission(final Permission... permissions) {
        Authentication authentication = getAuthentication();
        return hasPermission(authentication, Arrays.asList(permissions), "");
    }

    public boolean hasLoggedInUserPermission(Permission permission, String onConfigurationItem) {
        return hasLoggedInUserPermission(Collections.singletonList(permission), onConfigurationItem);
    }

    public boolean hasLoggedInUserPermission(List<Permission> permissions, String onConfigurationItem) {
        return hasPermission(getAuthentication(), permissions, onConfigurationItem);
    }

    public void applyLoggedInUserPermission(SearchParameters parameters, Permission permission) {
        applyLoggedInUserPermission(parameters, Collections.singletonList(permission));
    }

    public void applyLoggedInUserPermission(SearchParameters parameters, List<Permission> permissions) {
        applyPermission(parameters, getAuthentication(), permissions);
    }

    public boolean hasPermission(Authentication auth, List<Permission> permissions, String onConfigurationItem) {
        final Collection<String> allPrincipals = authenticationToPrincipals(auth);
        List<Role> allRoles = getUserRoles(auth);
        return isAdmin(allPrincipals, allRoles) || hasPermission(allRoles, permissions, onConfigurationItem);
    }

    public void applyPermission(SearchParameters parameters, Authentication auth, List<Permission> permissions) {
        final Collection<String> allPrincipals = authenticationToPrincipals(auth);
        List<Role> allRoles = getUserRoles(auth);
        if (!isAdmin(allPrincipals, allRoles)) {
            applyPermission(parameters, allRoles, permissions);
        }
    }

    public List<Role> getUserRoles(Authentication auth) {
        return roleService.getRolesFor(auth);
    }

    public boolean hasPermission(List<Role> roles, List<Permission> permissions, String onConfigurationItem) {
        return checker.checkPermission(permissions, onConfigurationItem, roles);
    }

    public void applyPermission(SearchParameters parameters, List<Role> roles, List<Permission> permissions) {
        parameters.setSecurityParameters(
                roles.stream().map(Role::getId).collect(toList()),
                permissions.stream().map(Permission::getPermissionName).collect(toList())
        );
    }

    boolean isAdmin(Collection<String> allPrincipals, List<Role> allRoles, Authentication auth) {
        boolean isAdmin = allPrincipals.contains(ROLE_ADMIN) || checker.checkPermission(Collections.singletonList(PlatformPermissions.ADMIN), "", allRoles, auth);
        logger.trace("Admin privileges [{}] granted to {}", isAdmin ? "are" : "are not", allPrincipals);
        return isAdmin;
    }

    public boolean isAdmin(Collection<String> allPrincipals, List<Role> allRoles) {
        return isAdmin(allPrincipals, allRoles, Permissions.getAuthentication());
    }

    private static final Logger logger = LoggerFactory.getLogger(PermissionEnforcer.class);

    public boolean isCurrentUserAdmin() {
        return isAdmin(getAuthentication());
    }

    public boolean isAdmin(Authentication auth) {
        Collection<String> principals = authenticationToPrincipals(auth);
        List<Role> allRoles = roleService.getRolesFor(auth);
        return isAdmin(principals, allRoles, auth);
    }
}
